"""ConventionalShavingDynamics"""

from __future__ import annotations

from typing import ClassVar, TYPE_CHECKING

from mastapy._private._internal import utility
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.python_net import python_net_import
from mastapy._private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics import (
    _790,
)

_CONVENTIONAL_SHAVING_DYNAMICS = python_net_import(
    "SMT.MastaAPI.Gears.Manufacturing.Cylindrical.AxialAndPlungeShavingDynamics",
    "ConventionalShavingDynamics",
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="ConventionalShavingDynamics")
    CastSelf = TypeVar(
        "CastSelf",
        bound="ConventionalShavingDynamics._Cast_ConventionalShavingDynamics",
    )


__docformat__ = "restructuredtext en"
__all__ = ("ConventionalShavingDynamics",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_ConventionalShavingDynamics:
    """Special nested class for casting ConventionalShavingDynamics to subclasses."""

    __parent__: "ConventionalShavingDynamics"

    @property
    def shaving_dynamics(self: "CastSelf") -> "_790.ShavingDynamics":
        return self.__parent__._cast(_790.ShavingDynamics)

    @property
    def conventional_shaving_dynamics(
        self: "CastSelf",
    ) -> "ConventionalShavingDynamics":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class ConventionalShavingDynamics(_790.ShavingDynamics):
    """ConventionalShavingDynamics

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _CONVENTIONAL_SHAVING_DYNAMICS

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def cast_to(self: "Self") -> "_Cast_ConventionalShavingDynamics":
        """Cast to another type.

        Returns:
            _Cast_ConventionalShavingDynamics
        """
        return _Cast_ConventionalShavingDynamics(self)
